# frozen_string_literal: true

require 'spec_helper'

describe Roqua::CsvExport::ExportVersions do
  let(:export_versions_path) { RSPEC_ROOT_PATH.join('fixtures', 'export_versions') }
  subject(:export_versions) { described_class.new(export_versions_path) }

  describe '#[]' do
    it 'returns the json encoded in the file specified by key' do
      expect(export_versions['v201801']['date']).to eq '2018-01-01T01:00:00+01:00'
    end
  end

  describe '#dig' do
    it 'works' do
      expect(export_versions.dig('v201804', 'fields', 'all_quests', 0, 'key')) \
        .to eq 'roqua_id'
    end
  end

  describe '#keys' do
    it 'returns all the keys in order' do
      expect(export_versions.keys).to eq %w(v201801 v201802 v201803 v201804 v201809)
    end
  end

  describe '#mapping_for' do
    let(:keys) { %w(v1 v2 v3) }

    before do
      allow(export_versions).to receive(:keys).and_return keys
      allow(export_versions).to receive(:[]).with('v2').and_return \
        'fields' => {'all_quests' => {'v1' => 'v1_v2'}}
    end

    it 'returns the requested version if the questionnaire exists there' do
      expect(export_versions).to_not receive(:keys)
      expect(export_versions.mapping_for('all_quests', 'v2')).to eq \
        'v1' => 'v1_v2'
    end

    it 'returns the first export_version that does define the questionnaires' do
      expect(export_versions).to receive(:[]).with('v1').and_return \
        'fields' => {}
      expect(export_versions).to receive(:[]).with('v2')
      expect(export_versions.mapping_for('all_quests', 'v1')).to eq \
        'v1' => 'v1_v2'
    end
  end
end