# frozen_string_literal: true

require 'rspec'
require 'fabrication'
require File.join(File.expand_path(__dir__), '..', 'lib', 'roqua-csv_export')

RSPEC_ROOT_PATH = Pathname.new(__dir__).expand_path
SQLITE_PATH = RSPEC_ROOT_PATH.join('fixtures', 'sql_export.db')

Dir[File.join(File.expand_path(__dir__), 'support', '*.rb')].each { |f| require f }

RSpec.configure do |config|
  config.before(:context, :needs_db) do # not suite, since feature spec overwrites DB
    Sequel::Model.db = Sequel.sqlite
    Roqua::CsvExport.send(:load_db, Sequel::Model.db, SQLITE_PATH)
  end
  config.around(:each, :needs_db) do |each|
    Sequel::Model.db.transaction(:rollback=>:always, :auto_savepoint=>true) do 
      each.run
    end
  end
end
